import { Schema, Node as ProsemirrorNode } from 'prosemirror-model';
import { Plugin } from 'prosemirror-state';
import { Decoration, EditorView, NodeView } from 'prosemirror-view';
import { Subject } from 'rxjs';
declare type Content = string | Record<string, any> | null;
interface NodeViews {
    [name: string]: (node: ProsemirrorNode, view: EditorView, getPos: () => number, decorations: Decoration[]) => NodeView;
}
interface Options {
    content?: Content;
    enabled?: boolean;
    placeholder?: string;
    schema?: Schema;
    plugins?: Plugin[];
    nodeViews?: NodeViews;
}
declare class Editor {
    view: EditorView;
    options: Options;
    el: DocumentFragment;
    onContentChange: Subject<Record<string, null>>;
    onFocus: Subject<void>;
    onBlur: Subject<void>;
    onUpdate: Subject<unknown>;
    constructor(options?: Options);
    get schema(): Schema;
    setContent(content: Content): void;
    private handleTransactions;
    private createEditor;
    registerPlugin(plugin: Plugin): void;
    enable(): void;
    disable(): void;
    setPlaceholder(placeholder: string): void;
    destroy(): void;
}
export default Editor;
